@@ -27,7 +27,7 @@ s3client = s3.meta.client
 def upload_file(
     file,
     bucket=cfg('amazon.bucket'),
-    directory=cfg('mode').lower(),
+    directory=cfg('amazon.directory'),
     file_type=None,
 ):
     """ Upload file """
